package de.mcs.utils.event;

import org.junit.After;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

public class TestEventFactory {

  private MyEvent1 event1;
  private MyEvent2 event2;
  private EventFactory factory;
  private boolean doEvent1;
  private boolean doEvent2;

  class MyEvent1 extends AbstractEvent {

    public MyEvent1() {
      super(MyEvent1.class.getSimpleName());
    }

    private MyEvent1(String name) {
      super(name);
    }

  }

  class MyEvent2 extends AbstractEvent {

    public MyEvent2() {
      super(MyEvent2.class.getSimpleName());
    }

    private MyEvent2(String name) {
      super(name);
    }

  }

  @Before
  public void setUp() throws Exception {
    event1 = new MyEvent1();
    event2 = new MyEvent2();
    factory = new EventFactory();
    factory.registerEvent(event1);
    factory.registerEvent(event2);
  }

  @After
  public void tearDown() throws Exception {
  }

  @Test
  public void testRegisterEvent() {
    Assert.assertTrue("event 1 not registered. ", factory.isEventRegistered(event1));
    Assert.assertTrue("event 2 not registered. ", factory.isEventRegistered(event2));
  }

  @Test
  public void testRegisterListener() {
    resetEventValues();

    EventListener listener = new EventListener() {

      @Override
      public void handle(String event, Object... data) {
        doEvent1 = event.equals(event1.getName());
        doEvent2 = event.equals(event2.getName());
      }
    };
    factory.registerListener(event1, listener);

    Assert.assertTrue(factory.isListenerRegistered(event1, listener));

    Assert.assertFalse(doEvent1);
    Assert.assertFalse(doEvent2);

    factory.fireEvent(event1, "nix da");

    Assert.assertTrue(doEvent1);
    Assert.assertFalse(doEvent2);

    resetEventValues();

    factory.fireEvent(event2, "nix da");

    Assert.assertFalse(doEvent1);
    Assert.assertFalse(doEvent2);

    resetEventValues();

    factory.unregisterListener(event1, listener);

    factory.fireEvent(event1, "nix da");
    factory.fireEvent(event2, "nix da");

    Assert.assertFalse(doEvent1);
    Assert.assertFalse(doEvent2);

    factory.registerListener(event1, listener);
    factory.registerListener(event2, listener);
    Assert.assertTrue(factory.isListenerRegistered(event1, listener));
    Assert.assertTrue(factory.isListenerRegistered(event2, listener));

    resetEventValues();

    Assert.assertFalse(doEvent1);
    Assert.assertFalse(doEvent2);

    factory.fireEvent(event1, "nix da");

    Assert.assertTrue(doEvent1);
    Assert.assertFalse(doEvent2);

    factory.fireEvent(event2, "nix da");

    Assert.assertFalse(doEvent1);
    Assert.assertTrue(doEvent2);
  }

  @Test
  public void testAutoDeRegisterListener() {
    resetEventValues();

    EventListener listener = new EventListener() {

      @Override
      public void handle(String event, Object... data) {
        doEvent1 = event.equals(event1.getName());
        doEvent2 = event.equals(event2.getName());
      }
    };
    factory.registerListener(event1, listener);

    Assert.assertFalse(doEvent1);
    Assert.assertFalse(doEvent2);

    factory.fireEvent(event1, (Object) null);

    Assert.assertTrue(doEvent1);
    Assert.assertFalse(doEvent2);

    listener = null;
    resetEventValues();
    System.gc();

    factory.fireEvent(event1, (Object) null);

    Assert.assertFalse(doEvent1);
    Assert.assertFalse(doEvent2);
  }

  private void resetEventValues() {
    doEvent1 = false;
    doEvent2 = false;
  }
}
